pub struct NoteBuilder { /* private fields */ }Expand description
Builder for Note.
Implementations
Sourceimpl NoteBuilder
impl NoteBuilder
pub fn deck_name(&mut self, value: String) -> &mut Self
pub fn model_name(&mut self, value: String) -> &mut Self
pub fn options(&mut self, value: NoteOptions) -> &mut Self
pub fn audios(&mut self, value: Vec<Media>) -> &mut Self
pub fn videos(&mut self, value: Vec<Media>) -> &mut Self
pub fn pictures(&mut self, value: Vec<Media>) -> &mut Self
Sourceimpl NoteBuilder
impl NoteBuilder
pub fn field(&mut self, field_name: &str, value: &str) -> &mut Self
Sourcepub fn extend_fields(
&mut self,
append: impl IntoIterator<Item = (String, String)>,
) -> &mut Self
pub fn extend_fields( &mut self, append: impl IntoIterator<Item = (String, String)>, ) -> &mut Self
Appends current fields with an Iterator<(field_name, content)>;
Sourcepub async fn build(&mut self, client: Option<&Client>) -> AnkiResult<Note>
pub async fn build(&mut self, client: Option<&Client>) -> AnkiResult<Note>
Builds a new note with its media as bytes.
Information
MediaSource::Url => Downloads verified url::Url data & converts to base64. MediaSource::Path => Calls tokio::fs::read on the PathBuf. MediaSource::Data => Returns the data directly. Expected that the bytes are base64 encoded. Should return an error later by checking encoding.
If you created all media using builder using only data field directly,
it will not make any internal requests.